replace_words_dict = {
    'اله': 'الله',
    'متاز': 'ممتاز',
    'متازه': 'ممتازة',
    'ومتازه': 'وممتازة',
    'ومتاز': 'وممتاز',
    'ماشاءله': 'ماشاء الله',
    'ماشاء له': 'ماشاء الله',
    'الون': 'اللون',
    'والون': 'واللون',
    'الحمدله': 'الحمد لله',
    'الحمد له': 'الحمد لله',
    'يجن': 'يجنن',
    'تجن': 'تجنن',
    'بيجن': 'بيجنن',
#####
    'عد': 'عدد',
    'ما': 'مما',
    'بسب': 'بسبب',
    'الغه': 'اللغة',
    'الملكه': 'المملكة',
    'است': 'أسست',
    'الام': 'اللام',
    'بالغه': 'باللغة',
    'في': 'ففى',
    'العد': 'العدد',
    'متعده': 'متعددة',
    'ملكه': 'مملكة',
    'مثل': 'ممثل',
    'سب': 'سبب',
    'مثله': 'ممثلة',
    'تغير': 'تتغير',
    'تكون': 'تتكون',
    'ملاين': 'ملايين',
    'اس': 'أسس',
    'مءسه': 'مؤسسة',
    'السب': 'السبب',
    'الغات': 'اللغات',
    'مءس': 'مؤسس',
    'وعد': 'ووعد',
    'تبع': 'تتبع',
    'المكن': 'الممكن',
    'تعين': 'تعيين',
    'لحصول': 'للحصول',
    'تميز': 'تتميز',
    'افتاح': 'افتتاح',
    'تاست': 'تأسست',
    'تسب': 'تسبب',
    'لتقويم': 'للتقويم',
    'المءسات': 'المؤسسات',
    'لمره': 'للمرة',
    'تراوح': 'تتراوح',
    'تضمن': 'تتضمن',
    'الجنه': 'اللجنة',
    'قر': 'قرر',
    'تم': 'تتم',
    'لدوله': 'للدولة',
    'الاتينيه': 'اللاتينية',
    'اللون': 'اللون',
    'بناء': 'ببناء',
    'لغايه': 'للغاية',
    'من': 'ممن',
    'وبسب': 'وبسبب',
    'لعديد': 'للعديد',
    'وضع': 'ووضع',
    'لام': 'للامم',
    'تمتع': 'تتمتع',
    'لعمل': 'للعمل',
    'محده': 'محددة',
    'الازمه': 'اللازمة',
    'بعض': 'ببعض',
    'عدهم': 'عددهم',
    'مارسه': 'ممارسة',
    'لعد': 'للعدد',
    'تعلق': 'تتعلق',
    'لسلام': 'للسلام',
    'لقوات': 'للقوات',
    'ماثله': 'مماثلة',
    'لحكومه': 'للحكومة',
    'بعد': 'بعدد',
    'عدا': 'عددا',
    'المءسه': 'المؤسسة',
    'لمدينه': 'للمدينة',
    'الاحقه': 'اللاحقة',
    'النوي': 'النووي',
    'المسيحين': 'المسيحيين',
    'لجيش': 'للجيش',
    'تالف': 'تتألف',
    'لولايات': 'للولايات',
    'متعد': 'متعدد',
    'لعلوم': 'للعلوم',
    'اليل': 'الليل',
    'النويه': 'النووية',
    'مءسات': 'مؤسسات',
    'لبلاد': 'للبلاد',
    'عدها': 'عددها',
    'السك': 'السكك',
    'والملكه': 'والمملكة',
    'تحق': 'تحقق',
    'خط': 'خطط',
    'تحد': 'تحدد',
    'الاصلين': 'الأصليين',
    'وصل': 'ووصل',
    'المصرين': 'المصريين',
    'التميز': 'التمييز',
    'حق': 'حقق',
    'وتكون': 'وتتكون',
    'لاتحاد': 'للإتحاد',
    'تجاوز': 'تتجاوز',
    'يسب': 'يسبب',
    'المتعده': 'المتعددة',
    'لطاقه': 'للطاقة',
    'والغه': 'واللغة',
    'تمثل': 'تتمثل',
    'يحد': 'يحدد',
    'تاس': 'تأسس',
    'لاشاره': 'للإشارة',
    'قرت': 'قررت',
    'لوصول': 'للوصول',
    'لحكم': 'للحكم',
    'التغيرات': 'التغييرات',
    'الامريكين': 'الأمريكيين',
    'تطلب': 'تتطلب',
    'لحفاظ': 'للحفاظ',
    'ميزه': 'مميزة',
    'وتميز': 'وتمييز',
    'تواجد': 'تتواجد',
    'محد': 'محدد',
    'لنظام': 'للنظام',
    'الفرنسين': 'الفرنسيين',
    'لتعليم': 'للتعليم',
    'لملك': 'للملك',
    'المتده': 'الممتدة',
    'افتح': 'افتتح',
    'لدفاع': 'للدفاع',
    'مخط': 'مخطط',
    'لغه': 'للغة',
    'بير': 'بيير',
    'لسكان': 'للسكان',
    'لجمهوريه': 'للجمهورية',
    'بالون': 'باللون',
    'وزير': 'ووزير',
    'لسيطره': 'للسيطرة',
    'العثمانين': 'العثمانيين',
    'لبحث': 'للبحث',
    'لرءيس': 'للرئيس',
    'تخذ': 'تتخذ',
    'الميزه': 'المميزة',
    'البنانيه': 'اللبنانية',
    'لفنون': 'للفنون',
    'القب': 'اللقب',
    'الاوروبين': 'الأوروبيين',
    'اسها': 'أسسها',
    'المحلين': 'المحليين',
    'باله': 'بالله',
    'حقت': 'حققت',
    'بساطه': 'ببساطة',
    'المالك': 'الممالك',
    'وما': 'ومما',
    'تعرض': 'تتعرض',
    'السياسين': 'السياسيين',
    'لحزب': 'للحزب',
    'قص': 'قصص',
    'مخصه': 'مخصصة',
    'لحياه': 'للحياة',
    'مءسي': 'مؤسسي',
    'الاجءين': 'اللاجئين',
    'البناني': 'اللبناني',
    'اثبت': 'أثبتت',
    'تحدث': 'تتحدث',
    'تقيم': 'تقييم',
    'لشعب': 'للشعب',
    'معاير': 'معايير',
    'تغيرات': 'تغييرات',
    'لقيام': 'للقيام',
    'حد': 'حدد',
    'لنشر': 'للنشر',
    'توفر': 'تتوفر',
    'لثقافه': 'للثقافة',
    'واس': 'وأسس',
    'ومثل': 'وممثل',
    'لقرن': 'للقرن',
    'لدراسات': 'للدراسات',
    'والمءسات': 'والمؤسسات',
    'يتسب': 'يتسبب',
    'بتعين': 'بتعيين',
    'السوفيتي': 'السوفييتي',
    'تقر': 'تقرر',
    'وفقا': 'ووفقا',
    'لمنطقه': 'للمنطقة',
    'لاستخدام': 'للاستخدام',
    'التغير': 'التغيير',
    'البريطانين': 'البريطانيين',
    'تحول': 'تتحول',
    'تحرك': 'تتحرك',
    'لفرد': 'للفرد',
    'مكن': 'ممكن',
    'لعالم': 'للعالم',
    'المقر': 'المقرر',
    'يحق': 'يحقق',
    'تعد': 'تتعدد',
    'وصف': 'ووصف',
    'تسبت': 'تسببت',
    'لتجاره': 'للتجارة',
    'المتخصه': 'المتخصصة',
    'لدلاله': 'للدلالة',
    'العسكرين': 'العسكريين',
    'لتنميه': 'للتنمية',
    'وجد': 'وجدد',
    'تشيد': 'تشييد',
    'لامبراطوريه': 'للإمبراطورية',
    'لحرب': 'للحرب',
    'لتعبير': 'للتعبير',
    'القص': 'القصص',
    'المخط': 'المخطط',
    'لسلطه': 'للسلطة',
    'لحد': 'للحد',
    'له': 'لله',
    'المعاير': 'المعايير',
    'لاطفال': 'للأطفال',
    'الفلسطينين': 'الفلسطينيين',
    'الجوء': 'اللجوء',
    'المخصه': 'المخصصة',
    'لملكه': 'للمملكة',
    'لمساعده': 'للمساعدة',
    'الطيف': 'اللطيف',
    'ترد': 'تتردد',
    'الذان': 'اللذان',
    'المثل': 'الممثل',
    'الفظ': 'اللفظ',
    'وجه': 'ووجهة',
    'المحده': 'المحددة',
    'لجدل': 'للجدل',
    'المارسه': 'الممارسة',
    'لمسلمين': 'للمسلمين',
    'تاثر': 'تتأثر',
    'المدنين': 'المدنيين',
    'لقضاء': 'للقضاء',
    'لزراعه': 'للزراعة',
    'لحركه': 'للحركة',
    'الازم': 'اللازم',
    'يقل': 'يقلل',
    'الماليك': 'المماليك',
    'لدول': 'للدول',
    'بتغير': 'بتغيير',
    'الواء': 'اللواء',
    'الهجه': 'اللهجة',
    'الجد': 'الجدد',
    'لثوره': 'للثورة',
    'لانسان': 'للإنسان',
    'ومءس': 'ومؤسس',
    'بعضها': 'ببعضها',
    'ماثل': 'مماثل',
    'وقع': 'ووقع',
    'افتحت': 'افتتحت',
    'لناس': 'للناس',
    'وسب': 'وسبب',
    'الغوي': 'اللغوي',
    'ات': 'أتت',
    'بطء': 'ببطء',
    'يمكنا': 'يمكننا',
    'لكتاب': 'للكتاب',
    'المارسات': 'الممارسات',
    'تعينه': 'تعيينه',
    'وصلت': 'ووصلت',
    'لمشاركه': 'للمشاركة',
    'واله': 'والله',
    'متخصه': 'متخصصة',
    'تشكل': 'تتشكل',
    'لكنيسه': 'للكنيسة',
    'تفاعل': 'تتفاعل',
    'لانضمام': 'للانضمام',
    'متاليه': 'متتالية',
    'ليهود': 'لليهود',
    'لوزراء': 'للوزراء',
    'لماده': 'للمادة',
    'لارض': 'للأرض',
    'نويه': 'نووية',
    'مخص': 'مخصص',
    'الوحات': 'اللوحات',
    'تفك': 'تفكك',
    'يقر': 'يقرر',
    'اليبيه': 'الليبية',
    'لشيخ': 'للشيخ',
    'توقف': 'تتوقف',
    'وسط': 'ووسط',
    'ومثله': 'وممثلة',
    'تايد': 'تأييد',
    'مالك': 'ممالك',
    'توافق': 'تتوافق',
    'الملاين': 'الملايين',
    'لاسلام': 'للإسلام',
    'وجود': 'ووجود',
    'الهجات': 'اللهجات',
    'الحظه': 'اللحظة',
    'وملكه': 'ومملكة',
    'الذين': 'اللذين',
    'المءس': 'المؤسس',
    'لمواد': 'للمواد',
    'لمجلس': 'للمجلس',
    'الاتيني': 'اللاتيني',
    'فينا': 'فيينا',
    'لمياه': 'للمياه',
    'لجنه': 'للجنة',
    'بالغات': 'باللغات',
    'تجه': 'تتجه',
    'المتكره': 'المتكررة',
    'نوي': 'نووي',
    'الملوكه': 'المملوكة',
    'لنقل': 'للنقل',
    'الاس': 'الأسس',
    'لفتره': 'للفترة',
    'مصم': 'مصمم',
    'وادي': 'ووادي',
    'تركز': 'تتركز',
    'مر': 'مرر',
    'تمكن': 'تتمكن',
    'تطور': 'تتطور',
    'تويج': 'تتويج',
    'لمجتمع': 'للمجتمع',
    'لتراث': 'للتراث',
    'سك': 'سكك',
    'مثلين': 'ممثلين',
    'صم': 'صمم',
    'تيح': 'تتيح',
    'الوحه': 'اللوحة',
    'لنساء': 'للنساء',
    'وتسب': 'وتتسبب',
    'ومءسات': 'ومؤسسات',
    'تخص': 'تخصص',
    'لموسيقي': 'للموسيقى',
    'لعناصر': 'للعناصر',
    'لقانون': 'للقانون',
    'القاء': 'اللقاء',
    'وقر': 'وقرر',
    'حدت': 'حددت',
    'الصليبين': 'الصليبيين',
    'انا': 'اننا',
    'ترك': 'تترك',
    'لشباب': 'للشباب',
    'الخط': 'الخطط',
    'لابحاث': 'للأبحاث',
    'والغات': 'واللغات',
    'الثديات': 'الثدييات',
    'تناول': 'تتناول',
    'تصل': 'تتصل',
    'لاعمال': 'للأعمال',
    'لدراسه': 'للدراسة',
    'لهجره': 'للهجرة',
    'لاراضي': 'للأراضي',
    'الرءيسين': 'الرئيسيين',
    'الغويه': 'اللغوية',
    'وساءل': 'ووسائل',
    'متكره': 'متكررة',
    'لعيش': 'للعيش',
    'لعام': 'للعام',
    'الميز': 'المميز',
    'المحد': 'المحدد',
    'لرجال': 'للرجال',
    'وتعين': 'وتعيين',
    'الضر': 'الضرر',
    'لتاريخ': 'للتاريخ',
    'مكنه': 'ممكنة',
    'الحوم': 'اللحوم',
    'لمناطق': 'للمناطق',
    'تقل': 'تقلل',
    'التحق': 'التحقق',
    'واحده': 'وواحدة',
    'اليله': 'الليلة',
    'ملوكه': 'مملوكة',
    'ميزات': 'مميزات',
    'الصينين': 'الصينيين',
    'قم': 'قمم',
    'تولي': 'تتولى',
    'وتضمن': 'وتتضمن',
    'سبا': 'سببا',
    'لكثير': 'للكثير',
    'لاقتصاد': 'للاقتصاد',
    'وضعت': 'ووضعت',
    'لطباعه': 'للطباعة',
    'لمعلومات': 'للمعلومات',
    'وقعت': 'ووقعت',
    'وقف': 'ووقف',
    'والسب': 'والسبب',
    'لاشخاص': 'للأشخاص',
    'وافق': 'ووافق',
    'وتراوح': 'وتتراوح',
    'المثله': 'الممثلة',
    'لجمعيه': 'للجمعية',
    'لعهد': 'للعهد',
    'الغربين': 'الغربيين',
    'لسماح': 'للسماح',
    'التحر': 'التحرر',
    'تناسب': 'تتناسب',
    'لكشف': 'للكشف',
    'تسم': 'تسمم',
    'لبحر': 'للبحر',
    'لكاتب': 'للكاتب',
    'اليبي': 'الليبي',
    'لمراه': 'للمرأة',
    'مارسات': 'ممارسات',
    'م': 'مم',
    'الترد': 'التردد',
    'مثلي': 'ممثلي',
    'متخص': 'متخصص',
    'البيزنطين': 'البيزنطيين',
    'لطيران': 'للطيران',
    'لكيمياء': 'للكيمياء',
    'الحم': 'اللحم',
    'يتحق': 'يتحقق',
    'متكر': 'متكرر',
    'تفق': 'تتفق',
    'فقر': 'فقرر',
    'لتخلص': 'للتخلص',
    'متلكات': 'ممتلكات',
    'تحكم': 'تتحكم',
    'بطوله': 'ببطولة',
    'تعامل': 'تتعامل',
    'لشءون': 'للشؤون',
    'جد': 'جدد',
    'التخصات': 'التخصصات',
    'مخطات': 'مخططات',
    'مجدا': 'مجددا',
    'لتعامل': 'للتعامل',
    'يهد': 'يهدد',
    'لاداره': 'للإدارة',
    'لقتال': 'للقتال',
    'لعراق': 'للعراق',
    'الورد': 'اللورد',
    'وجدت': 'ووجدت',
    'ولايه': 'وولاية',
    'المتلكات': 'الممتلكات',
    'دانيل': 'دانييل',
    'وتالف': 'وتتألف',
    'لهجوم': 'للهجوم',
    'لتغير': 'للتغيير',
    'التين': 'اللتين',
    'لنبي': 'للنبي',
    'المءسين': 'المؤسسين',
    'وحق': 'وحقق',
    'لطلاب': 'للطلاب',
    'وحده': 'ووحدة',
    'لفن': 'للفن',
    'وتبع': 'وتتبع',
    'لتربيه': 'للتربية',
    'بالملكه': 'بالمملكة',
    'لمحافظه': 'للمحافظة',
    'تعدي': 'تتعدى',
    'لمارسه': 'لممارسة',
    'التان': 'اللتان',
    'السان': 'اللسان',
    'العب': 'اللعب',
    'لتكنولوجيا': 'للتكنولوجيا',
    'لنفط': 'للنفط',
    'اليونانين': 'اليونانيين',
    'توزع': 'تتوزع',
    'وافتح': 'وافتتح',
    'المرات': 'الممرات',
    'العبه': 'اللعبة',
    'كل': 'ككل',
    'لانتخابات': 'للانتخابات',
    'ميز': 'مميز',
    'لعصر': 'للعصر',
    'ديغو': 'دييغو',
    'لشركات': 'للشركات',
    'لمدن': 'للمدن',
    'فانا': 'فإننا',
    'واسوا': 'وأسسوا',
    'بالغتين': 'باللغتين',
    'عز': 'عزز',
    'مرات': 'ممرات',
    'مصمه': 'مصممة',
    'تدفق': 'تتدفق',
    'لجميع': 'للجميع',
    'اليابانين': 'اليابانيين',
    'اسوا': 'أسسوا',
    'لعلماء': 'للعلماء',
    'لسيارات': 'للسيارات',
    'المكنه': 'الممكنة',
    'الملوكي': 'المملوكي',
    'لامام': 'للأمام',
    'بات': 'باتت',
    'المخص': 'المخصص',
    'اليبراليه': 'الليبرالية',
    'مقايس': 'مقاييس',
    'واصل': 'وواصل',
    'لعلم': 'للعلم',
    'تعز': 'تعزز',
    'الشيوعين': 'الشيوعيين',
    'لدكتور': 'للدكتور',
    'الفاطمين': 'الفاطميين',
    'وتغير': 'وتتغير',
    'صمت': 'صممت',
    'لمواطنين': 'للمواطنين',
    'يءس': 'يؤسس',
    'لضوء': 'للضوء',
    'ممتازة': 'ممتازة',
    'والام': 'والأمم',
    'الاسراءيلين': 'الإسرائيليين',
    'لصناعات': 'للصناعات',
    'لاثار': 'للآثار',
    'تسع': 'تتسع',
    'تقيد': 'تقييد',
    'الاهوت': 'اللاهوت',
    'لعوده': 'للعودة',
    'واحد': 'وواحد',
    'لجمهور': 'للجمهور',
    'المتد': 'الممتد',
    'لتعاون': 'للتعاون',
    'التعديه': 'التعددية',
    'والمسيحين': 'والمسيحيين',
    'اليبرالي': 'الليبرالي',
    'الغتين': 'اللغتين',
    'لسياحه': 'للسياحة',
    'لجزاءر': 'للجزائر',
    'عبداله': 'عبدالله',
    'السوفيت': 'السوفييت',
    'مهده': 'مهددة',
    'تهد': 'تهدد',
    'لسلطان': 'للسلطان',
    'لشمس': 'للشمس',
    'افتاحه': 'افتتاحه',
    'لشخص': 'للشخص',
    'لتحكم': 'للتحكم',
    'الاموين': 'الأمويين',
    'تشابه': 'تتشابه',
    'بيع': 'ببيع',
    'لقطاع': 'للقطاع',
    'البن': 'اللبن',
    'ملكته': 'مملكته',
    'لغزو': 'للغزو',
    'لدين': 'للدين',
    'الموسيقين': 'الموسيقيين',
    'محي': 'محيي',
    'لهندسه': 'للهندسة',
    'لاستيلاء': 'للاستيلاء',
    'لحضاره': 'للحضارة',
    'لحديث': 'للحديث',
    'العراقين': 'العراقيين',
    'مات': 'ماتت',
    'الواتي': 'اللواتي',
    'هد': 'هدد',
    'لغات': 'للغات',
    'المتاليه': 'المتتالية',
    'تجمع': 'تتجمع',
    'وتم': 'وتتم',
    'الجزاءرين': 'الجزائريين',
    'لميلاد': 'للميلاد',
    'ورد': 'وورد',
    'ولي': 'وولى',
    'لامير': 'للأمير',
    'الاعبين': 'اللاعبين',
    'لاتصالات': 'للاتصالات',
    'المر': 'الممر',
    'وتمتع': 'وتتمتع',
    'لاستفاده': 'للاستفادة',
    'لتدريب': 'للتدريب',
    'لاحتلال': 'للاحتلال',
    'تضرت': 'تضررت',
    'لعلاقات': 'للعلاقات',
    'ذو': 'ذوو',
    'العباسين': 'العباسيين',
    'لتحقيق': 'للتحقيق',
    'تلقي': 'تتلقى',
    'البرتغالين': 'البرتغاليين',
    'التجس': 'التجسس',
    'وزاره': 'ووزارة',
    'تحل': 'تتحلل',
    'حقه': 'حققه',
    'لخطوط': 'للخطوط',
    'لاصلاح': 'للإصلاح',
    'لاطاحه': 'للإطاحة',
    'لسك': 'لسكك',
    'لتقيم': 'لتقييم',
    'لماء': 'للماء',
    'لاهتمام': 'للاهتمام',
    'لتاكد': 'للتأكد',
    'وتمثل': 'وتتمثل',
    'ومءسه': 'ومؤسسة',
    'يفتح': 'يفتتح',
    'لملاحه': 'للملاحة',
    'الصحفين': 'الصحفيين',
    'الاحق': 'اللاحق',
    'لشاعر': 'للشاعر',
    'المقايس': 'المقاييس',
    'المثلين': 'المثليين',
    'لخدمات': 'للخدمات',
    'المتاز': 'الممتاز',
    'لسفر': 'للسفر',
    'تجد': 'تجدد',
    'سبه': 'سببه',
    'الوطنين': 'الوطنيين',
    'لاحتفال': 'للاحتفال',
    'غابريل': 'غابرييل',
    'تسير': 'تسيير',
    'لاغراض': 'للأغراض',
    'لقران': 'للقرآن',
    'ام': 'أمم',
    'القم': 'القمم',
    'لكلمه': 'للكلمة',
    'سبها': 'سببها',
    'الرياضين': 'الرياضيين',
    'لجسم': 'للجسم',
    'لاحصاء': 'للإحصاء',
    'لوحده': 'للوحدة',
    'لحراره': 'للحرارة',
    'تمركز': 'تتمركز',
    'وجها': 'وجهها',
    'عزت': 'عززت',
    'لذكور': 'للذكور',
    'لاله': 'للآلة',
    'لبيءه': 'للبيئة',
    'لدستور': 'للدستور',
    'لكتابه': 'للكتابة',
    'لشركه': 'للشركة',
    'لعرب': 'للعرب',
    'والاتينيه': 'واللاتينية',
    'تعارض': 'تتعارض',
    'اسه': 'أسسه',
    'وعدهم': 'ووعدهم',
    'لبحوث': 'للبحوث',
    'القومين': 'القوميين',
    'لمركبات': 'للمركبات',
    'لفيزياء': 'للفيزياء',
    'متده': 'ممتدة',
    'لخلافه': 'للخلافة',
    'لنظر': 'للنظر',
    'تعدت': 'تعددت',
    'الغد': 'الغدد',
    'لمطالبه': 'للمطالبة',
    'رءيسين': 'رئيسيين',
    'المهده': 'المهددة',
    'خصت': 'خصصت',
    'تداخل': 'تتداخل',
    'لادب': 'للأدب',
    'لتفاعل': 'للتفاعل',
    'بمارسه': 'بممارسة',
    'تابع': 'تتابع',
    'لسنه': 'للسنة',
    'الفينيقين': 'الفينيقيين',
    'لبشر': 'للبشر',
    'لكهرباء': 'للكهرباء',
    'لشعر': 'للشعر',
    'لمجموعه': 'للمجموعة',
    'يترد': 'يتردد',
    'بالهجه': 'باللهجة',
    'تحمل': 'تتحمل',
    'وتاست': 'وتأسست',
    'لسفن': 'للسفن',
    'لاشعه': 'للأشعة',
    'لمسيحين': 'للمسيحيين',
    'تفاوت': 'تتفاوت',
    'مفخه': 'مفخخة',
    'محر': 'محرر',
    'الاسلامين': 'الإسلاميين',
    'المتعد': 'المتعدد',
    'لقوه': 'للقوة',
    'لطبيعه': 'للطبيعة',
    'لضغط': 'للضغط',
    'لولايه': 'للولاية',
    'الشرقين': 'الشرقيين',
    'المنوحه': 'الممنوحة',
    'لعلاج': 'للعلاج',
    'لمءرخ': 'للمؤرخ',
    'لاسم': 'للاسم',
    'لدخول': 'للدخول',
    'لمستخدمين': 'للمستخدمين',
    'لمءسه': 'للمؤسسة',
    'لنشاط': 'للنشاط',
    'لخطر': 'للخطر',
    'لاستثمار': 'للاستثمار',
    'لمرء': 'للمرء',
    'لجامعه': 'للجامعة',
    'وتركز': 'وتتركز',
    'اليليه': 'الليلية',
    'لمحكمه': 'للمحكمة',
    'لعنصر': 'للعنصر',
    'الايطالين': 'الإيطاليين',
    'لخليفه': 'للخليفة',
    'لمسجد': 'للمسجد',
    'الملوكيه': 'المملوكية',
    'لاستقلال': 'للاستقلال',
    'لخروج': 'للخروج',
    'لخدمه': 'للخدمة',
    'لطب': 'للطب',
    'خص': 'خصص',
    'لتفاوض': 'للتفاوض',
    'لاجءين': 'للاجئين',
    'لفلسفه': 'للفلسفة',
    'المتخص': 'المتخصص',
    'لسياسه': 'للسياسة',
    'لتوسع': 'للتوسع',
    'وحد': 'وحدد',
    'لمسيحيه': 'للمسيحية',
    'تحر': 'تتحرر',
    'لامبراطور': 'للإمبراطور',
    'تنوع': 'تتنوع',
    'لكره': 'للكرة',
    'توسط': 'تتوسط',
    'لامه': 'للأمة',
    'لمدرسه': 'للمدرسة',
    'لعاصمه': 'للعاصمة',
    'سبت': 'سببت',
    'تمد': 'تتمدد',
    'لالعاب': 'للألعاب',
    'وعدها': 'وعددها',
    'تكر': 'تتكرر',
    'المعمارين': 'المعماريين',
    'لصناعه': 'للصناعة',
    'لانتاج': 'للإنتاج',
    'الحن': 'اللحن',
    'لاسره': 'للأسرة',
    'لامراض': 'للأمراض',
    'لسياح': 'للسياح',
    'الافتاح': 'الافتتاح',
    'السورين': 'السوريين',
    'وصفه': 'ووصفه',
    'لاسلحه': 'للأسلحة',
    'الاعب': 'اللاعب',
    'الاتي': 'اللاتي',
    'يخط': 'يخطط',
    'لكويت': 'للكويت',
    'ومارسه': 'وممارسة',
    'وفاه': 'ووفاة',
    'وضعها': 'ووضعها',
    'ثبت': 'ثبتت',
    'لمنظمه': 'للمنظمة',
    'لحيوانات': 'للحيوانات',
    'السعودين': 'السعوديين',
    'لبحريه': 'للبحرية',
    'لبيانات': 'للبيانات',
    'الاشورين': 'الآشوريين',
    'وتقر': 'وتقرر',
    'الجان': 'اللجان',
    'لوحدات': 'للوحدات',
    'مءسها': 'مؤسسها',
    'لبرلمان': 'للبرلمان',
    'ومن': 'وممن',
    'الوح': 'اللوح',
    'مياه': 'مياهه',
    'ويحد': 'ويحدد',
    'تقدم': 'تتقدم',
    'لمءتمر': 'للمؤتمر',
    'لحدود': 'للحدود',
    'لطبقه': 'للطبقة',
    'لتعرف': 'للتعرف',
    'لغاز': 'للغاز',
    'تخصات': 'تخصصات',
    'بلاد': 'ببلاد',
    'التخص': 'التخصص',
    'لصلاه': 'للصلاة',
    'مياها': 'مياهها',
    'ويسب': 'ويسبب',
    'لاتصال': 'للاتصال',
    'لقوي': 'للقوى',
    'لرعايه': 'للرعاية',
    'المسبه': 'المسببة',
    'اني': 'إنني',
    'يعز': 'يعزز',
    'تصرف': 'تتصرف',
    'خل': 'خلل',
    'الوم': 'اللوم',
    'مثلا': 'ممثلا',
    'وتوفر': 'وتتوفر',
    'لشعوب': 'للشعوب',
    'لمذهب': 'للمذهب',
    'لفكر': 'للفكر',
    'تطابق': 'تتطابق',
    'السوفيتيه': 'السوفييتية',
    'خافير': 'خافيير',
    'لسب': 'لسبب',
    'التحل': 'التحلل',
    'لاذاعه': 'للإذاعة',
    'Grek': 'Greek',
    'لقاء': 'للقاء',
    'وتحد': 'وتحدد',
    'لبلدان': 'للبلدان',
    'لبيع': 'للبيع',
    'لانتقال': 'للانتقال',
    'العديه': 'العددية',
    'وتواجد': 'وتتواجد',
    'تحقت': 'تحققت',
    'مسيحين': 'مسيحيين',
    'وضعه': 'ووضعه',
    'وضعوا': 'ووضعوا',
    'لدعوه': 'للدعوة',
    'الشراين': 'الشرايين',
    'اليالي': 'الليالي',
    'والسك': 'والسكك',
    'تصف': 'تتصف',
    'لاصابه': 'للإصابة',
    'تغذي': 'تتغذى',
    'لتواصل': 'للتواصل',
    'لظروف': 'للظروف',
    'لفنان': 'للفنان',
    'لعمليات': 'للعمليات',
    'والذان': 'واللذان',
    'لموقع': 'للموقع',
    'الهم': 'اللهم',
    'الايرانين': 'الإيرانيين',
    'لمسرح': 'للمسرح',
    'داود': 'داوود',
    'لجسيمات': 'للجسيمات',
    'لجهاز': 'للجهاز',
    'لطاءرات': 'للطائرات',
    'لاشراف': 'للإشراف',
    'عسكرين': 'عسكريين',
    'لتميز': 'للتميز',
    'لتدخل': 'للتدخل',
    'تشيده': 'تشييده',
    'لصيد': 'للصيد',
    'القروين': 'القرويين',
    'المتكر': 'المتكرر',
    'تبني': 'تتبنى',
    'وقرت': 'وقررت',
    'لتعريف': 'للتعريف',
    'لحمايه': 'للحماية',
    'لاحداث': 'للأحداث',
    'لطرق': 'للطرق',
    'باقي': 'بباقي',
    'وفاته': 'ووفاته',
    'لمعاير': 'لمعايير',
    'والده': 'ووالدة',
    'لبنك': 'للبنك',
    'الباس': 'اللباس',
    'بملكه': 'بمملكة',
    'لمركز': 'للمركز',
    'لجزء': 'للجزء',
    'الحالين': 'الحاليين',
    'وتسبت': 'وتسببت',
    'بالاتينيه': 'باللاتينية',
    'لتاج': 'للتاج',
    'وتخذ': 'وتتخذ',
    'العدي': 'العددي',
    'الديمقراطين': 'الديمقراطيين',
    'ويليام': 'وويليام',
    'تضر': 'تضرر',
    'ول': 'وول',
    'لاستعمار': 'للاستعمار',
    'المخطات': 'المخططات',
    'وصفها': 'ووصفها',
    'لديمقراطيه': 'للديمقراطية',
    'لمستخدم': 'للمستخدم',
    'تزايد': 'تتزايد',
    'تخط': 'تخطط',
    'تشارك': 'تتشارك',
    'تدخل': 'تتدخل',
    'لاعلام': 'للإعلام',
    'والمارسات': 'والممارسات',
    'لارقام': 'للأرقام',
    'لرياضه': 'للرياضة',
    'لتقدم': 'للتقدم',
    'اليزر': 'الليزر',
    'المتجده': 'المتجددة',
    'لاقامه': 'للإقامة',
    'والمالك': 'والممالك',
    'لعماره': 'للعمارة',
    'تبعها': 'تتبعها',
    'لافراد': 'للأفراد',
    'لمقاومه': 'للمقاومة',
    'والقص': 'والقصص',
    'لنمو': 'للنمو',
    'لصحه': 'للصحة',
    'لسوق': 'للسوق',
    'صمه': 'صممه',
    'تخلها': 'تتخللها',
    'لجماعه': 'للجماعة',
    'لالكترونات': 'للإلكترونات',
    'صوت': 'صوتت',
    'لحاله': 'للحالة',
    'لرابطه': 'للرابطة',
    'لجبه': 'للجبهة',
    'لبناء': 'للبناء',
    'لتاثير': 'للتأثير',
    'رواءين': 'روائيين',
    'مدوح': 'ممدوح',
    'لرياح': 'للرياح',
    'وكاله': 'ووكالة',
    'لسكن': 'للسكن',
    'لمءلف': 'للمؤلف',
    'لاجسام': 'للأجسام',
    'الوثريه': 'اللوثرية',
    'لمشروع': 'للمشروع',
    'لامن': 'للأمن',
    'حايم': 'حاييم',
    'ممتاز': 'ممتاز',
    'التايد': 'التأييد',
    'بتشيد': 'بتشييد',
    'لصين': 'للصين',
    'لجزيره': 'للجزيرة',
    'لعمال': 'للعمال',
    'ترجم': 'تترجم',
    'لمغرب': 'للمغرب',
    'لذهاب': 'للذهاب',
    'و': 'وو',
    'الحج': 'الحجج',
    'والتميز': 'والتمييز',
    'لنظريه': 'للنظرية',
    'المتخصين': 'المتخصصين',
    'واست': 'وأسست',
    'حدها': 'حددها',
    'الدولين': 'الدوليين',
    'قل': 'قلل',
    'لسيدات': 'للسيدات',
    'لكون': 'للكون',
    'برنامج': 'ببرنامج',
    'بلديه': 'ببلدية',
    'الوفر': 'اللوفر',
    'لمنتجات': 'للمنتجات',
    'لخلايا': 'للخلايا',
    'الصد': 'الصدد',
    'بدء': 'ببدء',
    'لفصل': 'للفصل',
    'كمثل': 'كممثل',
    'لالكترون': 'للإلكترون',
    'المسب': 'المسبب',
    'وافتحت': 'وافتتحت',
    'البنانين': 'اللبنانيين',
    'الواءح': 'اللوائح',
    'لكاءنات': 'للكائنات',
    'لعباده': 'للعبادة',
    'الاشتراكين': 'الاشتراكيين',
    'لوجود': 'للوجود',
    'الاميركين': 'الأميركيين',
    'يتكر': 'يتكرر',
    'الجمهورين': 'الجمهوريين',
    'لوقايه': 'للوقاية',
    'لموارد': 'للموارد',
    'تزوج': 'تتزوج',
    'لتخطيط': 'للتخطيط',
    'لشرب': 'للشرب',
    'الحظات': 'اللحظات',
    'تكيف': 'تتكيف',
    'لانظمه': 'للأنظمة',
    'لكتب': 'للكتب',
    'تكلم': 'تتكلم',
    'فيها': 'ففيها',
    'لحاكم': 'للحاكم',
    'لانديه': 'للأندية',
    'باريس': 'بباريس',
    'اسراءيلين': 'إسرائيليين',
    'لملكيه': 'للملكية',
    'جث': 'جثث',
    'التقيم': 'التقييم',
    'لنقد': 'للنقد',
    'لبقاء': 'للبقاء',
    'وحدات': 'ووحدات',
    'لشرطه': 'للشرطة',
    'تشت': 'تشتت',
    'الافتاحيه': 'الافتتاحية',
    'تفرع': 'تتفرع',
    'لمعرفه': 'للمعرفة',
    'لمرضي': 'للمرضى',
    'لعاءله': 'للعائلة',
    'والدته': 'ووالدته',
    'وحقت': 'وحققت',
    'تولد': 'تتولد',
    'لرجل': 'للرجل',
    'التعين': 'التعيين',
    'لشريعه': 'للشريعة',
    'لزواج': 'للزواج',
    'لهيءه': 'للهيئة',
    'الماثله': 'المماثلة',
    'لديانه': 'للديانة',
    'والسياسين': 'والسياسيين',
    'مثلو': 'ممثلو',
    'الاقطاعين': 'الإقطاعيين',
    'وفق': 'ووفق',
    'لجامعات': 'للجامعات',
    'الهولندين': 'الهولنديين',
    'تساقط': 'تتساقط',
    'الجغرافين': 'الجغرافيين',
    'مدنين': 'مدنيين',
    'وتنوع': 'وتتنوع',
    'القاءات': 'اللقاءات',
    'لترويج': 'للترويج',
    'لروم': 'للروم',
    'لزوار': 'للزوار'
}




import unittest

from ruqiya.ruqiya import clean_text


class TestSimple(unittest.TestCase):


    def test_clean_text(self):

        text="""
        !!أهلًا وسهلًا بك 👋 في الإصدارِ الأولِ من مكتبة رقيا
        هل هذه هي المرة الأولى التي تستخدم فيها المكتبة😀؟!!
        معلومات التواصل 
        ايميل
        example@email.com
        الموقع
        https://pypi.org/project/ruqia/
        تويتر
        @Ru0Sa
        وسم
        #معالجة_العربية
                """
        
        expected_text = """
وسهلا  الاصدار  مكتبه رقيا  المره  تستخدم المكتبه معلومات التواصل ايميل الموقع تويتر وسم معالجه العربيه
        """
        
        cleaned_text = clean_text(text)
        
        self.assertEqual(cleaned_text, expected_text.strip())
if __name__ == '__main__':
    unittest.main()




from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()
long_description = (here / "README.md").read_text(encoding="utf-8")

setup(
    name="ruqia",  # Required
    version="0.0.23",  # Required
    description="Arabic NLP",  # Optional
    long_description=long_description,  # Optional
    long_description_content_type="text/markdown",  # Optional (see note above)
    url="https://github.com/Ruqyai/Ruqia-Library",  # Optional
    author="Ruqiya Bin Safi",  # Optional
    author_email="",  # Optional
    classifiers=[  # Optional
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords="Arabic, NLP, development",  # Optional
    package_dir={"": "src"},  # Optional
    packages=find_packages(where="src"),  # Required
    python_requires=">=3.7, <4",
    install_requires=["peppercorn"],  # Optional
    extras_require={  # Optional
        "dev": ["check-manifest"],
        "test": ["coverage"],
    },
    package_data={  # Optional
        "ruqiya": ["package_data.dat"],
    },
    data_files=[("my_data", ["data/data_file"])],  # Optional
    entry_points={  # Optional
        "console_scripts": [
            "ruqiya=ruqiya:main",
        ],
    },
    project_urls={  # Optional
        "Bug Reports": "https://github.com/Ruqyai/Ruqia-Library/issues",
        "Become a sponsor": "https://github.com/sponsors/Ruqyai",
        "Source": "https://github.com/Ruqyai/Ruqia-Library",
    },
)
